==> ovirt-engine-sdk-java-4.1.1.tar.gz: ovirt-engine-sdk-java-4.1.1/target/generated-sources/org/ovirt/engine/sdk4/services/TemplateWatchdogsService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.math.BigInteger;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.WatchdogBuilder;
import org.ovirt.engine.sdk4.types.Watchdog;

public interface TemplateWatchdogsService extends Service {
    public interface AddRequest extends Request<AddRequest, AddResponse> {
        AddRequest watchdog(Watchdog watchdog);
        AddRequest watchdog(WatchdogBuilder watchdog);
    }
    
    public interface AddResponse extends Response {
        Watchdog watchdog();
    }
    
    AddRequest add();
    
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Sets the maximum number of watchdogs to return. If not specified all the watchdogs are returned.
         */
        ListRequest max(Integer max);
        /**
         * Sets the maximum number of watchdogs to return. If not specified all the watchdogs are returned.
         */
        ListRequest max(Long max);
        /**
         * Sets the maximum number of watchdogs to return. If not specified all the watchdogs are returned.
         */
        ListRequest max(BigInteger max);
    }
    
    public interface ListResponse extends Response {
        List<Watchdog> watchdogs();
    }
    
    ListRequest list();
    
    TemplateWatchdogService watchdogService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

==> ovirt-engine-sdk-java-4.1.6.tar.gz: ovirt-engine-sdk-java-4.1.6/target/generated-sources/org/ovirt/engine/sdk4/services/TemplateWatchdogsService.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.math.BigInteger;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.WatchdogBuilder;
import org.ovirt.engine.sdk4.types.Watchdog;

public interface TemplateWatchdogsService extends Service {
    public interface AddRequest extends Request<AddRequest, AddResponse> {
        AddRequest watchdog(Watchdog watchdog);
        AddRequest watchdog(WatchdogBuilder watchdog);
    }
    
    public interface AddResponse extends Response {
        Watchdog watchdog();
    }
    
    AddRequest add();
    
    /**
     * Returns the list of watchdogs.
     * 
     * The order of the returned list of watchdogs isn't guaranteed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Sets the maximum number of watchdogs to return. If not specified all the watchdogs are returned.
         */
        ListRequest max(Integer max);
        /**
         * Sets the maximum number of watchdogs to return. If not specified all the watchdogs are returned.
         */
        ListRequest max(Long max);
        /**
         * Sets the maximum number of watchdogs to return. If not specified all the watchdogs are returned.
         */
        ListRequest max(BigInteger max);
    }
    
    /**
     * Returns the list of watchdogs.
     * 
     * The order of the returned list of watchdogs isn't guaranteed.
     */
    public interface ListResponse extends Response {
        List<Watchdog> watchdogs();
    }
    
    /**
     * Returns the list of watchdogs.
     * 
     * The order of the returned list of watchdogs isn't guaranteed.
     */
    ListRequest list();
    
    TemplateWatchdogService watchdogService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}
